interact

package
v0.14.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateIssue

func CreateIssue(ctx context.Context, login *config.Login, owner, repo string) error

CreateIssue interactively creates an issue

func CreateLogin

func CreateLogin(ctx context.Context) error

CreateLogin create an login interactive

func CreateMilestone

func CreateMilestone(requestCtx stdctx.Context, login *config.Login, owner, repo string) error

CreateMilestone interactively creates a milestone

func CreatePull

func CreatePull(requestCtx stdctx.Context, ctx *context.TeaContext) (err error)

CreatePull interactively creates a PR

func DoDiffReview

func DoDiffReview(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64) ([]gitea.CreatePullReviewComment, error)

DoDiffReview (1) fetches & saves diff in tempfile, (2) starts $VISUAL or $EDITOR to comment on diff, (3) parses resulting file into code comments. It doesn't really make sense to use survey.Editor() here, as we'd read the file content at least twice.

func EditIssue

func EditIssue(requestCtx stdctx.Context, ctx context.TeaContext, index int64) (*task.EditIssueOption, error)

EditIssue interactively edits an issue

func IsQuitting

func IsQuitting(err error) bool

IsQuitting checks if the user has aborted the interactive prompt

func IsStdinPiped

func IsStdinPiped() bool

IsStdinPiped checks if stdin is piped

func MergePull

func MergePull(requestCtx stdctx.Context, ctx *context.TeaContext) error

MergePull interactively creates a PR

func PromptPassword

func PromptPassword(name string) (pass string, err error)

PromptPassword asks for a password and blocks until input was made.

func ReviewPull

func ReviewPull(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64) error

ReviewPull interactively reviews a PR

func ShowCommentsMaybeInteractive

func ShowCommentsMaybeInteractive(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64, totalComments int) error

ShowCommentsMaybeInteractive fetches & prints comments, depending on the --comments flag. If that flag is unset, and output is not piped, prompts the user first.

func ShowCommentsPaginated

func ShowCommentsPaginated(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64, totalComments int) error

ShowCommentsPaginated prompts if issue/pr comments should be shown and continues to do so.

Types

This section is empty.

Jump to