Documentation
¶
Index ¶
- func CreateIssue(ctx context.Context, login *config.Login, owner, repo string) error
- func CreateLogin(ctx context.Context) error
- func CreateMilestone(requestCtx stdctx.Context, login *config.Login, owner, repo string) error
- func CreatePull(requestCtx stdctx.Context, ctx *context.TeaContext) (err error)
- func DoDiffReview(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64) ([]gitea.CreatePullReviewComment, error)
- func EditIssue(requestCtx stdctx.Context, ctx context.TeaContext, index int64) (*task.EditIssueOption, error)
- func IsQuitting(err error) bool
- func IsStdinPiped() bool
- func MergePull(requestCtx stdctx.Context, ctx *context.TeaContext) error
- func PromptPassword(name string) (pass string, err error)
- func ReviewPull(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64) error
- func ShowCommentsMaybeInteractive(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64, ...) error
- func ShowCommentsPaginated(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateIssue ¶
CreateIssue interactively creates an issue
func CreateLogin ¶
CreateLogin create an login interactive
func CreateMilestone ¶
CreateMilestone interactively creates a milestone
func CreatePull ¶
func CreatePull(requestCtx stdctx.Context, ctx *context.TeaContext) (err error)
CreatePull interactively creates a PR
func DoDiffReview ¶
func DoDiffReview(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64) ([]gitea.CreatePullReviewComment, error)
DoDiffReview (1) fetches & saves diff in tempfile, (2) starts $VISUAL or $EDITOR to comment on diff, (3) parses resulting file into code comments. It doesn't really make sense to use survey.Editor() here, as we'd read the file content at least twice.
func EditIssue ¶
func EditIssue(requestCtx stdctx.Context, ctx context.TeaContext, index int64) (*task.EditIssueOption, error)
EditIssue interactively edits an issue
func IsQuitting ¶
IsQuitting checks if the user has aborted the interactive prompt
func MergePull ¶
func MergePull(requestCtx stdctx.Context, ctx *context.TeaContext) error
MergePull interactively creates a PR
func PromptPassword ¶
PromptPassword asks for a password and blocks until input was made.
func ReviewPull ¶
ReviewPull interactively reviews a PR
func ShowCommentsMaybeInteractive ¶
func ShowCommentsMaybeInteractive(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64, totalComments int) error
ShowCommentsMaybeInteractive fetches & prints comments, depending on the --comments flag. If that flag is unset, and output is not piped, prompts the user first.
func ShowCommentsPaginated ¶
func ShowCommentsPaginated(requestCtx stdctx.Context, ctx *context.TeaContext, idx int64, totalComments int) error
ShowCommentsPaginated prompts if issue/pr comments should be shown and continues to do so.
Types ¶
This section is empty.